---
name: Feature request
about: Suggest an idea for Talkie
title: '[FEATURE] '
labels: enhancement
assignees: ''
---

## Problem

A clear description of the problem. Ex. I'm always frustrated when [...]

## Proposed solution

Describe the solution you'd like.

## Alternatives considered

Describe any alternative solutions or features you've considered.

## Additional context

Add any other context or screenshots about the feature request here.
